clear
set more off
capture log close

set mem 5g

set matsize 800

clear matrix


cap log close
log using ${log}Table1.log, replace

use ${data}finalsample_dario_pt.dta, clear

***Define skill groups
gen skill_inddef1=personeffect+xb
forvalues i=10(10)90 {
bys year: egen bound`i'=pctile(skill_inddef1), p(`i')
}
gen skill_def2=.
replace skill_def2=1 if skill_inddef1<=bound10
replace skill_def2=2 if skill_inddef1>bound10 & skill_inddef1<=bound20
replace skill_def2=3 if skill_inddef1>bound20 & skill_inddef1<=bound30
replace skill_def2=4 if skill_inddef1>bound30 & skill_inddef1<=bound40
replace skill_def2=5 if skill_inddef1>bound40 & skill_inddef1<=bound50
replace skill_def2=6 if skill_inddef1>bound50 & skill_inddef1<=bound60
replace skill_def2=7 if skill_inddef1>bound60 & skill_inddef1<=bound70
replace skill_def2=8 if skill_inddef1>bound70 & skill_inddef1<=bound80
replace skill_def2=9 if skill_inddef1>bound80 & skill_inddef1<=bound90
replace skill_def2=10 if skill_inddef1>bound90
sort pnr year
save ${temp}data_pre_akm_all_pt_dor.dta, replace

********************************
****ANALYSIS OF DESIRED HOURS BASED ON THE DANISH LABOUR FORCE SURVEY (AKU)
********************************

use "F:\Data\Workdata\707562\DATA\views\doraku_raw.dta", clear

***keep only the spell of november (for comparison with lønstatistikken)
gen nov=0
replace nov=1 if (refweek>=44 & refweek<=48) & (year==2007)  
replace nov=1 if (refweek>=44 & refweek<=48) & (year==2008)  
replace nov=1 if (refweek>=44 & refweek<=49) & (year==2009)  
replace nov=1 if (refweek>=44 & refweek<=48) & (year==2010)  
replace nov=1 if (refweek>=44 & refweek<=48) & (year==2011)  
keep if nov==1

****keep employees employed in the reference week
keep if stapro==3 
keep if wstator==1

sort pnr year
merge pnr year using ${temp}data_pre_akm_all_pt_dor.dta, keep(ind_2 ind_3 ind_4 cvrnr skill_def1 skill_def2 )
keep if _merge==3
drop _merge

erase ${temp}data_pre_akm_all_pt_dor.dta
rename hwwish personeffect

***Use the same notation used in the tables 
rename skill_def1 skill_def0
rename skill_def2 skill_def1

********************************
***UPPER PANEL OF TABLE 1
********************************

***Descriptive stats on desired hours by skill group: column 1 of Table 1
svyset [pw=coeffq]
svy: mean personeffect, over(skill_def1)
bys skill_def1: tabstat personeffect, stat(N)

***Descriptive stats on desired hours by skill group: column 2 of Table 1
preserve
qui tab year, gen(yr)
egen indyear=group(ind_3)
qui tab indyear, gen(induyr) 
reg personeffect induyr*
predict res_hours, residuals
gen deshoursind=_b[_cons]+res_hours
svy: mean  deshoursin, over(skill_def1)
bys skill_def1: tabstat deshoursin, stat(N)
restore


********************************
****LOWER PANEL OF TABLE 1
********************************

***ROW 1 OF LOWER PANEL: MEAN STANDARD DEVIATION BETWEEN
preserve
bysort skill_def1 ind_4: egen mean_pref=mean(personeffect)
bysort skill_def1 ind_4: keep if _n==1
bysort ind_4: egen sd_btw=sd(mean_pref)
bysort ind_4: keep if _n==1
keep ind_4 sd_btw
sum sd_btw
sort ind_4
save ${data}between_var.dta, replace
restore

***ROW 2 OF LOWER PANEL: MEAN STANDARD DEVIATION WITHIN
preserve
bysort skill_def1 ind_4: egen sd_pref=sd(personeffect)
bysort skill_def1 ind_4: keep if _n==1
bysort ind_4: egen sd_with=mean(sd_pref)
bysort ind_4: keep if _n==1
keep ind_4  sd_with
sum sd_with
sort ind_4
merge ind_4  using ${data}between_var.dta
keep if _merge==3
drop _merge
sum sd_btw sd_with if sd_with!=. & sd_btw!=.
gen indgood=(sd_with!=. & sd_btw!=.)  
keep ind_4  indgood
sort ind_4
***make sure to merge with the same sample for the other statistics reported in the lower panel 
save ${data}industry_withobsdef1AKU.dta, replace
restore

***ROW 3 OF LOWER PANEL: MEAN 90/10 RATIO SKILL DEF. 1
preserve
bysort skill_def1 ind_4 : egen mean_pref=mean(personeffect)
bysort skill_def1 ind_4 : keep if _n==1
foreach i in 10 90 {
bysort ind_4 : egen p`i'between=pctile(mean_pref), p(`i')
}
gen r9010between=p90between/p10between
bysort ind_4 : keep if _n==1
keep ind_4 r9010between
sum r9010between
sort ind_4
save ${data}between_var.dta, replace
restore

***ROW 4 OF LOWER PANEL: MEAN 90/10 RATIO SKILL DEF. 1
preserve
foreach i in 10 90{
bysort skill_def1 ind_4 : egen p`i'within=pctile(personeffect), p(`i')
}
bysort skill_def1 ind_4 : keep if _n==1
gen r9010within=p90within/p10within
bysort ind_4 year: egen mr9010within=mean(r9010within)
drop r9010within
rename mr9010within r9010within
bysort ind_4 : keep if _n==1
keep ind_4 r9010within
sum r9010within
sort ind_4
merge ind_4 using ${data}between_var.dta
keep if _merge==3
drop _merge
sort ind_4
merge ind_4 using ${data}industry_withobsdef1AKU.dta
drop _m
sum r9010between r9010within if indgood==1
restore

***ROW 5 OF LOWER PANEL: MEAN 50/10 RATIO
preserve
bysort skill_def1 ind_4 : egen mean_pref=mean(personeffect)
bysort skill_def1 ind_4 : keep if _n==1
foreach i in 10 50 {
bysort ind_4 : egen p`i'between=pctile(mean_pref), p(`i')
}
gen r5010between=p50between/p10between
bysort ind_4 : keep if _n==1
keep ind_4  r5010between
sum r5010between
sort ind_4 
save ${data}between_var.dta, replace
restore

***ROW 6 OF LOWER PANEL: MEAN 50/10 RATIO
preserve
foreach i in 10 50{
bysort skill_def1 ind_4 : egen p`i'within=pctile(personeffect), p(`i')
}
bysort skill_def1 ind_4 : keep if _n==1
gen r5010within=p50within/p10within
bysort ind_4 year: egen mr5010within=mean(r5010within)
drop r5010within
rename mr5010within r5010within
bysort ind_4 : keep if _n==1
keep ind_4  r5010within
sum r5010within
sort ind_4
merge ind_4  using ${data}between_var.dta
keep if _merge==3
drop _merge
sort ind_4
merge ind_4 using ${data}industry_withobsdef1AKU.dta
drop _m
sum r5010between r5010within if indgood==1
restore

log close
